import 'dotenv/config';

import { createLog } from './log';
import type { Logger } from 'winston';
import { readFile, writeFile } from 'fs/promises';
import { join } from 'path';

import { DB } from './db';
import type { Photo } from './db';
import { envString } from './env';
import { Templates } from './templates';

class Build {
	private log : Logger;
	private tmpl : Templates;
	private db : DB;

	private www : string;

	constructor () {
		this.log = createLog('build');
		this.log.info(`Building site: ${new Date()}`);
		this.tmpl = new Templates();
		this.db = new DB();
		this.www = envString('WWW', './www');
		this.main();
	}

	private async main () {
		let photos : Photo[];
		let html : string;
		let data : any = {
			title : envString('TITLE', 'Unknown'),
			h1 : envString('H1', 'Unknown'),
			artist : envString('ARTIST', 'Unknown'),
			umami_url : envString('UMAMI_URL', null),
			umami_id : envString('UMAMI_ID', null),
			year : (new Date()).getFullYear()
		};
		let home : string = join(this.www, 'index.html');

		await this.tmpl.build();

		photos = await this.db.getAll();
		photos = photos.map((photo : Photo) => {
			photo.thumbHeight = Math.round((420.0 / photo.width) * photo.height) + 4;
			return photo;
		})
		html = await this.tmpl.render('index', { ...data, photos });

		try {
			await writeFile(home, html, 'utf8');
			this.log.info(`Wrote ${home}`);
		} catch (err) {
			this.log.error(`Error writing home page`, err);
		}
	}
}

new Build();